| Title: | Class of GARCH-Ito Models |
|---|---|
| Description: | Provides functions to estimate model parameters and forecast future volatilities using the Unified GARCH-Ito [Kim and Wang (2016) <doi:10.1016/j.jeconom.2016.05.003>] and Realized GARCH-Ito [Song et. al. (2020) <doi:10.1016/j.jeconom.2020.07.007>] models. Optimization is done using augmented Lagrange multiplier method. |
| Authors: | Xinyu Song |
| Maintainer: | Xinyu Song <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-09 04:57:59 UTC |
| Source: | https://github.com/cran/GARCHIto |
Estimate model parameters for the Realized GARCH-Ito Model
RealizedEst(RV = RV, JV = NULL)RealizedEst(RV = RV, JV = NULL)
RV |
Time series of daily realized volatilities. |
JV |
Time series of daily jump variations, |
Estimated parameter values and daily conditional volatilities:
parameter estimates of the realized GARCH-Ito model
daily conditional volatility estimates of the realized GARCH-Ito model
one-step-ahead predicted volatility value
Song, X., Kim, D., Yuan, H., Cui, X., Lu, Z., Zhou, Y., & Wang, Y. (2020). Volatility Analysis with Realized GARCH-Ito Models. Journal of Econometrics, in press.
sample_data RealizedEst(sample_data$RV) RealizedEst(sample_data$BPV, sample_data$JV)sample_data RealizedEst(sample_data$RV) RealizedEst(sample_data$BPV, sample_data$JV)
Estimate model parameters for the Realized GARCH-Ito Model with Options
RealizedEst_Option(RV = RV, JV = NULL, NV = NULL, homogeneous = TRUE)RealizedEst_Option(RV = RV, JV = NULL, NV = NULL, homogeneous = TRUE)
RV |
Time series of daily realized volatilities. |
JV |
Time series of daily jump variations, |
NV |
Time series of daily volatilities estimated using option data |
homogeneous |
Whether to assume homogeneous error in the linear regression model between conditional volatility of the realized GARCH-Ito model and volatility estimated from the option data, default is TRUE. |
Estimated parameter values and daily conditional volatilities:
parameter estimates of the realized GARCH-Ito model
daily conditional volatility estimates of the realized GARCH-Ito model
one-step-ahead predicted volatility value
Song, X., Kim, D., Yuan, H., Cui, X., Lu, Z., Zhou, Y., & Wang, Y. (2020). Volatility Analysis with Realized GARCH-Ito Models. Journal of Econometrics, in press.
This sample data set contains realized measures, such as realized volatility (RV), bi-power realized volatility (BPV) and jump variation (JV) estimated from CSI 300 Index high-frequency data, it also includes daily low-frequency log returns (return).
sample_datasample_data
An object with the following elements:
times series of daily realized volatility estimates
times series of daily bi-power realized volatility estimates
time series of daily jump variation estimates
time series of daily low-frequency returns
Estimate model parameters for the Unified GARCH-Ito Model.
UnifiedEst(RV = RV, return = return)UnifiedEst(RV = RV, return = return)
RV |
Time series of daily realized volatilities. |
return |
Time series of daily log returns. |
Estimated parameter values and daily conditional volatilities:
parameter estimates of the realized GARCH-Ito model
daily conditional volatility estimates of the realized GARCH-Ito model
one-step-ahead predicted volatility value
Kim, D. & Wang, Y. (2016). Unified discrete-time and continuous-time models and statistical inferences for merged low-frequency and high-frequency financial data. Journal of Econometrics. 194:220-230.
sample_data UnifiedEst(sample_data$RV, sample_data$return)sample_data UnifiedEst(sample_data$RV, sample_data$return)